@@ -48,7 +48,7 @@ uint AppChooserPortal::ChooseApplication(const QDBusObjectPath &handle,
     }
     AppChooserDialog *appDialog = new AppChooserDialog(choices, latestChoice, itemName.toString(), options.value(QStringLiteral("content_type")).toString());
     m_appChooserDialogs.insert(handle.path(), appDialog);
-    Utils::setParentWindow(appDialog, parent_window);
+    Utils::setParentWindow(appDialog->windowHandle(), parent_window);
 
     int result = appDialog->exec();
 
