@@ -13,6 +13,7 @@
 #include <QDBusMetaType>
 #include <QDialogButtonBox>
 #include <QFile>
+#include <QFileDialog>
 #include <QGridLayout>
 #include <QLabel>
 #include <QLoggingCategory>
@@ -255,6 +256,37 @@ uint FileChooserPortal::OpenFile(const QDBusObjectPath &handle,
         return retCode;
     }
 
+    // Use QFileDialog for most directory requests to utilize
+    // plasma-integration's KDirSelectDialog
+    if (directory && !options.contains(QStringLiteral("choices"))) {
+        QFileDialog dirDialog;
+        dirDialog.setWindowTitle(title);
+        dirDialog.setModal(modalDialog);
+        dirDialog.setFileMode(QFileDialog::Directory);
+        dirDialog.setOptions(QFileDialog::ShowDirsOnly);
+        dirDialog.setSupportedSchemes(QStringList{QStringLiteral("file")});
+        if (!acceptLabel.isEmpty()) {
+            dirDialog.setLabelText(QFileDialog::Accept, acceptLabel);
+        }
+
+        dirDialog.winId(); // Trigger window creation
+        Utils::setParentWindow(&dirDialog, parent_window);
+
+        if (dirDialog.exec() != QDialog::Accepted) {
+            return 1;
+        }
+
+        const auto urls = dirDialog.selectedUrls();
+        if (urls.empty()) {
+            return 2;
+        }
+
+        results.insert(QStringLiteral("uris"), QUrl::toStringList(urls));
+        results.insert(QStringLiteral("writable"), true);
+
+        return 0;
+    }
+
     // for handling of options - choices
     QScopedPointer<QWidget> optionsWidget;
     // to store IDs for choices along with corresponding comboboxes/checkboxes
@@ -272,6 +304,7 @@ uint FileChooserPortal::OpenFile(const QDBusObjectPath &handle,
     fileDialog->setModal(modalDialog);
     KFile::Mode mode = directory ? KFile::Mode::Directory : multipleFiles ? KFile::Mode::Files : KFile::Mode::File;
     fileDialog->m_fileWidget->setMode(mode | KFile::Mode::ExistingOnly);
+    fileDialog->m_fileWidget->setSupportedSchemes(QStringList{QStringLiteral("file")});
     fileDialog->m_fileWidget->okButton()->setText(!acceptLabel.isEmpty() ? acceptLabel : i18n("Open"));
 
     bool bMimeFilters = false;
@@ -287,19 +320,13 @@ uint FileChooserPortal::OpenFile(const QDBusObjectPath &handle,
     }
 
     if (fileDialog->exec() == QDialog::Accepted) {
-        QStringList files;
-        const auto selectedFiles = fileDialog->m_fileWidget->selectedFiles();
-        for (const QString &filename : selectedFiles) {
-            QUrl url = QUrl::fromLocalFile(filename);
-            files << url.toDisplayString();
-        }
-
-        if (files.isEmpty()) {
+        const auto urls = fileDialog->m_fileWidget->selectedUrls();
+        if (urls.isEmpty()) {
             qCDebug(XdgDesktopPortalKdeFileChooser) << "Failed to open file: no local file selected";
             return 2;
         }
 
-        results.insert(QStringLiteral("uris"), files);
+        results.insert(QStringLiteral("uris"), QUrl::toStringList(urls));
         results.insert(QStringLiteral("writable"), true);
 
         if (optionsWidget) {
