@@ -28,7 +28,7 @@ public:
     friend class FileChooserPortal;
 
     FileDialog(QDialog *parent = nullptr, Qt::WindowFlags flags = {});
-    ~FileDialog();
+    ~FileDialog() override;
 
 private:
     QDialogButtonBox *m_buttons;
@@ -71,7 +71,7 @@ public:
     typedef QList<Option> OptionList;
 
     explicit FileChooserPortal(QObject *parent);
-    ~FileChooserPortal();
+    ~FileChooserPortal() override;
 
 public Q_SLOTS:
     uint OpenFile(const QDBusObjectPath &handle,
@@ -103,7 +103,7 @@ private:
 
     static bool isMobile();
 
-    MobileFileDialog *m_mobileFileDialog;
+    MobileFileDialog *m_mobileFileDialog = nullptr;
 };
 
 #endif // XDG_DESKTOP_PORTAL_KDE_FILECHOOSER_H
