@@ -116,7 +116,7 @@ uint RemoteDesktopPortal::Start(const QDBusObjectPath &handle,
 
     QScopedPointer<RemoteDesktopDialog, QScopedPointerDeleteLater> remoteDesktopDialog(
         new RemoteDesktopDialog(app_id, session->deviceTypes(), session->screenSharingEnabled(), session->multipleSources()));
-    Utils::setParentWindow(remoteDesktopDialog.data(), parent_window);
+    Utils::setParentWindow(remoteDesktopDialog->windowHandle(), parent_window);
 
     connect(session, &Session::closed, remoteDesktopDialog.data(), &RemoteDesktopDialog::reject);
 
