@@ -139,10 +139,9 @@ uint ScreenCastPortal::Start(const QDBusObjectPath &handle,
         return 2;
     }
 
-    QScopedPointer<ScreenChooserDialog, QScopedPointerDeleteLater> screenDialog(new ScreenChooserDialog(app_id, session->multipleSources()));
-    Utils::setParentWindow(screenDialog.data(), parent_window);
-
-    screenDialog->setSourceTypes(SourceTypes(session->types()));
+    QScopedPointer<ScreenChooserDialog, QScopedPointerDeleteLater> screenDialog(
+        new ScreenChooserDialog(app_id, session->multipleSources(), SourceTypes(session->types())));
+    Utils::setParentWindow(screenDialog->windowHandle(), parent_window);
 
     connect(session, &Session::closed, screenDialog.data(), &ScreenChooserDialog::reject);
 
@@ -172,7 +171,6 @@ uint ScreenCastPortal::Start(const QDBusObjectPath &handle,
         if (inhibitionsEnabled()) {
             new NotificationInhibition(app_id, i18nc("Do not disturb mode is enabled because...", "Screen sharing in progress"), session);
         }
-
         return 0;
     }
 
